;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "emacsql" "20251116.1655"
  "High-level SQL database front-end."
  '((emacs "26.1"))
  :url "https://github.com/magit/emacsql"
  :commit "e1908de2cf2c7b77798ef6645d514dded1d7f8a4"
  :revdesc "e1908de2cf2c"
  :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
  :maintainers '(("Jonas Bernoulli" . "emacs.emacsql@jonas.bernoulli.dev")))
